@@ -1,6 +1,6 @@
 package Getopt::EX::Colormap;
 
-our $VERSION = "2.3.1";
+our $VERSION = "3.00";
 
 use v5.14;
 use utf8;
@@ -25,6 +25,7 @@ use Getopt::EX::Func qw(callable);
 use Term::ANSIColor::Concise qw(:all);
 {
     no strict 'refs';
+    no warnings 'once';
     *colorize   = \&ansi_color;
     *colorize24 = \&ansi_color_24;
     for my $name (
