@@ -1,6 +1,6 @@
 package Getopt::EX::Module;
 
-our $VERSION = "2.3.1";
+our $VERSION = "3.00";
 
 use v5.14;
 use warnings;
@@ -47,10 +47,10 @@ sub configure {
     }
 
     if (my $file = delete $opt{FILE}) {
-	if (open my $fh, "<:encoding(utf8)", $file) {
-	    $obj->module($file);
-	    $obj->readrc($fh);
-	}
+	open my $fh, "<:encoding(utf8)", $file
+	    or croak "Can't open file '$file': $!";
+	$obj->module($file);
+	$obj->readrc($fh);
     }
     elsif (my $module = delete $opt{MODULE}) {
 	my $pkg = $opt{PACKAGE} || 'main';
