@@ -1,6 +1,6 @@
 package Getopt::EX::Numbers;
 
-our $VERSION = "2.3.1";
+our $VERSION = "3.00";
 
 use v5.14;
 use warnings;
@@ -113,6 +113,9 @@ sub range {
     $length ||= 1;
     $step ||= $length;
 
+    # Ensure step is positive to avoid infinite loop
+    croak "step must be positive" if $step <= 0;
+
     my @l;
     if ($step == 1) {
 	@l = ( [$start, $end] );
